==> file_extractor-2.0.0-rc2.tar.gz: file_extractor/src/Plugin/Field/FieldFormatter/ExtractedText.php <==
<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\Plugin\Field\FieldFormatter;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\SubformState;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\file\Plugin\Field\FieldFormatter\FileFormatterBase;
use Drupal\file_extractor\ExtractionSettingsFormHelper;
use Drupal\file_extractor\Service\ExtractorManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * File formatter displaying text extracted form attachment document.
 *
 * @FieldFormatter(
 *   id = "file_extractor_extracted_text",
 *   label = @Translation("File Extractor: extracted file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class ExtractedText extends FileFormatterBase implements ContainerFactoryPluginInterface {

  /**
   * The extractor manager.
   *
   * @var \Drupal\file_extractor\Service\ExtractorManagerInterface
   */
  protected $extractorManager;

  /**
   * Class resolver service.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * ExtractedText constructor.
   *
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The field definitions.
   * @param array $settings
   *   The settings.
   * @param string $label
   *   The label.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   The third party settings.
   * @param \Drupal\file_extractor\Service\ExtractorManagerInterface $extractor_manager
   *   The extractor manager.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver service.
   */
  public function __construct(
    $plugin_id,
    $plugin_definition,
    FieldDefinitionInterface $field_definition,
    array $settings,
    $label,
    $view_mode,
    array $third_party_settings,
    ExtractorManagerInterface $extractor_manager,
    ClassResolverInterface $class_resolver
  ) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->extractorManager = $extractor_manager;
    $this->classResolver = $class_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $pluginDefinition) {
    return new static(
      $plugin_id,
      $pluginDefinition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('file_extractor.extractor_manager'),
      $container->get('class_resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'override_global_extraction_settings' => FALSE,
      'extraction_settings' => ExtractionSettingsFormHelper::DEFAULT_EXTRACTION_SETTINGS,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form['override_global_extraction_settings'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Override global extraction settings'),
      '#default_value' => $this->getSetting('override_global_extraction_settings'),
    ];

    $form['extraction_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Extraction settings'),
      '#open' => $this->getSetting('override_global_extraction_settings'),
      '#tree' => TRUE,
      '#states' => [
        'invisible' => [
          ':input[name$="[settings][override_global_extraction_settings]"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $form_state->setTemporary($this->getSetting('extraction_settings'));
    $extraction_settings_form_state = SubformState::createForSubform($form['extraction_settings'], $form, $form_state);
    $extraction_settings_form_helper = $this->classResolver->getInstanceFromDefinition(ExtractionSettingsFormHelper::class);
    $form['extraction_settings'] = $extraction_settings_form_helper->buildConfigurationForm($form['extraction_settings'], $extraction_settings_form_state);

    $form['#element_validate'] = [[get_class($this), 'validateSettingsForm']];
    return $form;
  }

  /**
   * Validate the settings form.
   */
  public static function validateSettingsForm($element, FormStateInterface $form_state, $form) {
    $extraction_settings_form_state = SubformState::createForSubform($element['extraction_settings'], $form, $form_state);
    $extraction_settings_form_helper = \Drupal::service('class_resolver')->getInstanceFromDefinition(ExtractionSettingsFormHelper::class);
    $extraction_settings_form_helper->validateConfigurationForm($element['extraction_settings'], $extraction_settings_form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    if (!$this->getSetting('override_global_extraction_settings')) {
      $summary[] = $this->t('Global extraction settings not overridden');
    }
    else {
      $summary[] = $this->t('Global extraction settings overridden. Overriden values:');
      $extraction_settings = $this->getSetting('extraction_settings');
      foreach ($extraction_settings as $extraction_setting_key => $extraction_setting_value) {
        $summary[] = $this->t('@extraction_setting_key: @extraction_setting_value', [
          '@extraction_setting_key' => $extraction_setting_key,
          '@extraction_setting_value' => $extraction_setting_value,
        ]);
      }
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    if ($this->getSetting('override_global_extraction_settings')) {
      $this->extractorManager->setExtractionSettings($this->getSetting('extraction_settings'));
    }

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $file) {
      /** @var \Drupal\file\FileInterface $file */
      $elements[$delta] = [
        '#markup' => $this->extractorManager->extract($file),
        '#cache' => [
          'tags' => $file->getCacheTags(),
        ],
      ];
    }

    return $elements;
  }

}

==> file_extractor-2.0.1.tar.gz: file_extractor/src/Plugin/Field/FieldFormatter/ExtractedText.php <==
<?php

declare(strict_types = 1);

namespace Drupal\file_extractor\Plugin\Field\FieldFormatter;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\SubformState;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\file\Plugin\Field\FieldFormatter\FileFormatterBase;
use Drupal\file_extractor\ExtractionSettingsFormHelper;
use Drupal\file_extractor\Service\ExtractorManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * File formatter displaying text extracted form attachment document.
 *
 * @FieldFormatter(
 *   id = "file_extractor_extracted_text",
 *   label = @Translation("File Extractor: extracted file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class ExtractedText extends FileFormatterBase implements ContainerFactoryPluginInterface {

  /**
   * The extractor manager.
   *
   * @var \Drupal\file_extractor\Service\ExtractorManagerInterface
   */
  protected $extractorManager;

  /**
   * Class resolver service.
   *
   * @var \Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * ExtractedText constructor.
   *
   * @param string $plugin_id
   *   The plugin id.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
   *   The field definitions.
   * @param array $settings
   *   The settings.
   * @param string $label
   *   The label.
   * @param string $view_mode
   *   The view mode.
   * @param array $third_party_settings
   *   The third party settings.
   * @param \Drupal\file_extractor\Service\ExtractorManagerInterface $extractor_manager
   *   The extractor manager.
   * @param \Drupal\Core\DependencyInjection\ClassResolverInterface $class_resolver
   *   The class resolver service.
   */
  public function __construct(
    $plugin_id,
    $plugin_definition,
    FieldDefinitionInterface $field_definition,
    array $settings,
    $label,
    $view_mode,
    array $third_party_settings,
    ExtractorManagerInterface $extractor_manager,
    ClassResolverInterface $class_resolver
  ) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $label, $view_mode, $third_party_settings);
    $this->extractorManager = $extractor_manager;
    $this->classResolver = $class_resolver;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $pluginDefinition) {
    return new static(
      $plugin_id,
      $pluginDefinition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['label'],
      $configuration['view_mode'],
      $configuration['third_party_settings'],
      $container->get('file_extractor.extractor_manager'),
      $container->get('class_resolver')
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return [
      'override_global_extraction_settings' => FALSE,
      'extraction_settings' => ExtractionSettingsFormHelper::DEFAULT_EXTRACTION_SETTINGS,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['override_global_extraction_settings'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Override global extraction settings'),
      '#default_value' => $this->getSetting('override_global_extraction_settings'),
    ];

    $form['extraction_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Extraction settings'),
      '#open' => $this->getSetting('override_global_extraction_settings'),
      '#tree' => TRUE,
      '#states' => [
        'invisible' => [
          ':input[name$="[settings][override_global_extraction_settings]"]' => ['checked' => FALSE],
        ],
      ],
    ];

    $form_state->setTemporary($this->getSetting('extraction_settings'));
    $extraction_settings_form_state = SubformState::createForSubform($form['extraction_settings'], $form, $form_state);
    $extraction_settings_form_helper = $this->classResolver->getInstanceFromDefinition(ExtractionSettingsFormHelper::class);
    $form['extraction_settings'] = $extraction_settings_form_helper->buildConfigurationForm($form['extraction_settings'], $extraction_settings_form_state);

    $form['#element_validate'] = [[get_class($this), 'validateSettingsForm']];
    return $form;
  }

  /**
   * Validate the settings form.
   */
  public static function validateSettingsForm($element, FormStateInterface $form_state, $form) {
    $extraction_settings_form_state = SubformState::createForSubform($element['extraction_settings'], $form, $form_state);
    $extraction_settings_form_helper = \Drupal::service('class_resolver')->getInstanceFromDefinition(ExtractionSettingsFormHelper::class);
    $extraction_settings_form_helper->validateConfigurationForm($element['extraction_settings'], $extraction_settings_form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    if (!$this->getSetting('override_global_extraction_settings')) {
      $summary[] = $this->t('Global extraction settings not overridden');
    }
    else {
      $summary[] = $this->t('Global extraction settings overridden. Overridden values:');
      $extraction_settings = $this->getSetting('extraction_settings');
      foreach ($extraction_settings as $extraction_setting_key => $extraction_setting_value) {
        $summary[] = $this->t('@extraction_setting_key: @extraction_setting_value', [
          '@extraction_setting_key' => $extraction_setting_key,
          '@extraction_setting_value' => $extraction_setting_value,
        ]);
      }
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];

    if ($this->getSetting('override_global_extraction_settings')) {
      $this->extractorManager->setExtractionSettings($this->getSetting('extraction_settings'));
    }

    foreach ($this->getEntitiesToView($items, $langcode) as $delta => $file) {
      /** @var \Drupal\file\FileInterface $file */
      $elements[$delta] = [
        '#markup' => $this->extractorManager->extract($file),
        '#cache' => [
          'tags' => $file->getCacheTags(),
        ],
      ];
    }

    return $elements;
  }

}
